# Episode Loader

__Download Podcast Episodes of Your Choice__

## What Does It Do
This is a simple package that does one thing really well:

## Dependencies
This package sits on the backs of giants. I would not really know how to do
this on my own.

- Requests
- Feedparser

**Given a Podcast RSS Feed it will:**

1. Give you a list of podcast episodes (thanks feedparser!)
2. Download the audio file associated with the requested episode (thanks
   requests)

Requirements:
* Python 3.8

